Documentation
¶
Overview ¶
Package exitcode centralizes cr's command-layer process exit taxonomy.
Index ¶
Constants ¶
const ( // Success means the program completed successfully. Success = 0 // Failure is the generic non-usage failure code. Failure = 1 // UsageError means command syntax, flags, or arguments were invalid. UsageError = 2 // AuthConfigError means authentication or configuration prevented execution. AuthConfigError = 3 // UpstreamError means an upstream service or network failure prevented execution. UpstreamError = 5 )
Variables ¶
This section is empty.
Functions ¶
func AuthConfig ¶
AuthConfig marks err as an authentication or configuration error.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.